@@ -80,63 +80,45 @@ hook_file_time(const gchar *filename)
 static gboolean
 hook_command_exists(const char *cmd)
 {
-   gboolean result = FALSE;
-   gchar *unquoted = NULL;
-   gchar **cargv = NULL;
-   GError *error = NULL;
+   g_autoptr(GError) error = NULL;
+   g_auto(GStrv) cargv = NULL;
+   g_autofree gchar *unquoted = NULL;
+   g_autofree gchar *path_to_cmd = NULL;
 
-   if(!cmd) goto out;
+   if(!cmd) return FALSE;
 
    unquoted = g_shell_unquote(cmd, &error);
    if(!unquoted) {
       g_debug_hooks("g_shell_unquote: %s", error->message);
-      goto out;
+      return FALSE;
    }
 
    gint cargc = 0;
-   cargv = NULL;
    if(!g_shell_parse_argv(unquoted, &cargc, &cargv, &error)) {
       g_debug_hooks("g_shell_parse_argv: %s", error->message);
-      goto out;
+      return FALSE;
    }
 
    if(cargc < 1) {
       g_debug_hooks("g_shell_parse_argv: unexpected output");
-      goto out;
+      return FALSE;
    }
 
-   if(cargv[0][0] == '/' &&
-	 g_file_test(cargv[0], G_FILE_TEST_EXISTS|G_FILE_TEST_IS_EXECUTABLE)) {
-      result = TRUE;
+   if(cargv[0][0] == '/' && g_file_test(cargv[0], G_FILE_TEST_IS_EXECUTABLE)) {
       g_debug_hooks("command exists");
-      goto out;
+      return TRUE;
    }
 
    g_debug_hooks("'%s' is not a valid absolute path", cargv[0]);
 
-   gchar **pathdirs = g_strsplit(getenv("PATH"), ":", 100);
-   if(!pathdirs) goto out;
-
-   for(int i = 0; pathdirs[i] != NULL; i++) {
-      gchar *pathdir = pathdirs[i];
-      char *fname = g_strdup_printf("%s/%s", pathdir, cargv[0]);
-      if(g_file_test(fname, G_FILE_TEST_EXISTS|G_FILE_TEST_IS_EXECUTABLE)) {
-	 g_debug_hooks("command exists at '%s'", fname);
-	 g_free(fname);
-	 result = TRUE;
-	 goto out;
-      }
-      g_free(fname);
+   path_to_cmd = g_find_program_in_path(cargv[0]);
+   if(path_to_cmd) {
+      g_debug_hooks("command found in PATH");
+      return TRUE;
    }
 
-   g_debug_hooks("failed to find command in PATH");
-
-out:
-   if(error) g_error_free(error);
-   if(cargv) g_strfreev(cargv);
-   if(pathdirs) g_strfreev(pathdirs);
-   if(unquoted) g_free(unquoted);
-   return result;
+   g_debug_hooks("failed to find command in PATH or directly");
+   return FALSE;
 }
 
 static gboolean
