@@ -192,16 +192,6 @@ invoke_with_pkexec(const gchar *cmd)
         g_spawn_async (NULL, argv, NULL, G_SPAWN_DEFAULT, NULL, NULL, NULL, NULL);
 }
 
-void
-avahi_disabled()
-{
-        g_debug("avahi disabled ()");
-        gchar *argv[2];
-        argv[0] = "/usr/lib/update-notifier/local-avahi-notification";
-        argv[1] = NULL;
-        g_spawn_async (NULL, argv, NULL, G_SPAWN_DEFAULT, NULL, NULL, NULL, NULL);
-}
-
 void livepatch_check()
 {
         g_debug("livepatch_check ()");
@@ -274,10 +264,6 @@ monitor_cb(GFileMonitor *handle,
       g_debug_inotify("crashreport found");
       un->crashreport_pending = TRUE;
    }
-   if(strstr(info_uri, UNICAST_LOCAL_AVAHI_FILE)) {
-      g_debug_inotify("avahi disabled due to unicast .local domain");
-      un->unicast_local_avahi_pending = TRUE;
-   }
    if(strstr(info_uri, LIVEPATCH_FILE)) {
       g_debug_inotify("livepatch status changed");
       un->livepatch_pending = TRUE;
@@ -292,7 +278,6 @@ monitor_cb(GFileMonitor *handle,
  *                    lists-dir, archive-cache, or /var/lib/dpkg/status)
  * - hook_pending: we have new upgrade hook information
  * - crashreport_pending: we have a new crashreport
- * - unicast_local_avahi_pending: avahi got disabled due to a unicast .local domain
  * - livepatch_pending: livepatch status changed
  *
  */
@@ -372,12 +357,6 @@ file_monitor_periodic_check(gpointer data)
       un->crashreport_pending = FALSE;
    }
 
-   if(un->unicast_local_avahi_pending) {
-      g_debug("checking for disabled avahi due to unicast .local domain now");
-      avahi_disabled ();
-      un->unicast_local_avahi_pending = FALSE;
-   }
-
   if(un->livepatch_pending) {
       g_debug("checking for livepatch status now");
       livepatch_check ();
@@ -426,13 +405,9 @@ monitor_init(UpgradeNotifier *un)
       "/var/lib/dpkg/status",
       "/var/lib/update-notifier/dpkg-run-stamp",
       "/var/lib/apt/periodic/update-success-stamp",
-      UNICAST_LOCAL_AVAHI_FILE,
       LIVEPATCH_FILE,
       NULL};
    for(i=0;monitor_files[i] != NULL;i++) {
-      if (getenv("UPSTART_SESSION") && monitor_files[i] == UNICAST_LOCAL_AVAHI_FILE) {
-         continue;
-      }
       GError *error = NULL;
       GFile *gf = g_file_new_for_path(monitor_files[i]);
       monitor_handle = g_file_monitor_file(gf, 0, NULL, &error);
